@@ -2,11 +2,7 @@ import asyncio
 import contextlib
 from typing import Union
 
-try:
-    from streamlit.server.Server import Server
-except Exception:
-    # Streamlit >= 0.65.0
-    from streamlit.server.server import Server
+from streamlit.server.server import Server
 
 
 def get_server_event_loop() -> asyncio.AbstractEventLoop:
